@@ -9,9 +9,9 @@ This module contains basic utility functions for
 creating and manipulating piddles. Most of these functions
 are simplified interfaces to the more flexible functions in
 the modules 
-L<PDL::Primitive|PDL::Primitive> 
+L<PDL::Primitive> 
 and 
-L<PDL::Slices|PDL::Slices>.
+L<PDL::Slices>.
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ use PDL::Options;
 =for ref
 
 Fills a piddle with X index values.  Uses similar specifications to
-L<zeroes|zeroes> and L<new_from_specification|new_from_specification>.
+L</zeroes> and L</new_from_specification>.
 
 CAVEAT: 
 
@@ -88,7 +88,7 @@ etc. see L<zeroes|PDL::Core/zeroes>.
 
 =for ref
 
-Fills a piddle with Y index values.  See the CAVEAT for L<xvals|xvals>.
+Fills a piddle with Y index values.  See the CAVEAT for L</xvals>.
 
 =for usage
 
@@ -117,7 +117,7 @@ etc. see L<zeroes|PDL::Core/zeroes>.
 
 =for ref
 
-Fills a piddle with Z index values.  See the CAVEAT for L<xvals|xvals>.
+Fills a piddle with Z index values.  See the CAVEAT for L</xvals>.
 
 =for usage
 
@@ -148,13 +148,13 @@ etc. see L<zeroes|PDL::Core/zeroes>.
 
 =for ref
 
-X axis values between endpoints (see L<xvals|/xvals>).
+X axis values between endpoints (see L</xvals>).
 
 =for usage
 
- $a = zeroes(100,100);
- $x = $a->xlinvals(0.5,1.5);
- $y = $a->ylinvals(-2,-1);
+ $w = zeroes(100,100);
+ $x = $w->xlinvals(0.5,1.5);
+ $y = $w->ylinvals(-2,-1);
  # calculate Z for X between 0.5 and 1.5 and
  # Y between -2 and -1.
  $z = f($x,$y);            
@@ -167,29 +167,29 @@ arguments along the given axis.
 
 =for ref
 
-Y axis values between endpoints (see L<yvals|/yvals>).
+Y axis values between endpoints (see L</yvals>).
 
-See L<xlinvals|/xlinvals> for more information.
+See L</xlinvals> for more information.
 
 =head2 zlinvals
 
 =for ref
 
-Z axis values between endpoints (see L<zvals|/zvals>).
+Z axis values between endpoints (see L</zvals>).
 
-See L<xlinvals|/xlinvals> for more information.
+See L</xlinvals> for more information.
 
 =head2 xlogvals
 
 =for ref
 
-X axis values logarithmically spaced between endpoints (see L<xvals|/xvals>).
+X axis values logarithmically spaced between endpoints (see L</xvals>).
 
 =for usage
 
- $a = zeroes(100,100);
- $x = $a->xlogvals(1e-6,1e-3);
- $y = $a->ylinvals(1e-4,1e3);
+ $w = zeroes(100,100);
+ $x = $w->xlogvals(1e-6,1e-3);
+ $y = $w->ylinvals(1e-4,1e3);
  # calculate Z for X between 1e-6 and 1e-3 and
  # Y between 1e-4 and 1e3.
  $z = f($x,$y);            
@@ -202,17 +202,17 @@ arguments along the given axis.
 
 =for ref
 
-Y axis values logarithmically spaced between endpoints (see L<yvals|/yvals>).
+Y axis values logarithmically spaced between endpoints (see L</yvals>).
 
-See L<xlogvals|/xlogvals> for more information.
+See L</xlogvals> for more information.
 
 =head2 zlogvals
 
 =for ref
 
-Z axis values logarithmically spaced between endpoints (see L<zvals|/zvals>).
+Z axis values logarithmically spaced between endpoints (see L</zvals>).
 
-See L<xlogvals|/xlogvals> for more information.
+See L</xlogvals> for more information.
 
 =cut
 
@@ -299,10 +299,10 @@ sub PDL::zlogvals {
 
 =for ref
 
-Synonym for L<ndcoords|ndcoords> - enumerates all coordinates in a
+Synonym for L</ndcoords> - enumerates all coordinates in a
 PDL or dim list, adding an extra dim on the front to accommodate
-the vector coordinate index (the form expected by L<indexND|indexND>,
-L<range|range>, and L<interpND|interpND>).  See L<ndcoords|ndcoords> for more detail.
+the vector coordinate index (the form expected by L</indexND>,
+L</range>, and L</interpND>).  See L</ndcoords> for more detail.
 
 =for usage
 
@@ -323,9 +323,9 @@ L<indexND|PDL::Slices/indexND> or L<range|PDL::Slices/range>: you feed
 in a dimension list and get out a piddle whose 0th dimension runs over
 dimension index and whose 1st through Nth dimensions are the
 dimensions given in the input.  If you feed in a piddle instead of a
-perl list, then the dimension list is used, as in L<xvals|xvals> etc.
+perl list, then the dimension list is used, as in L</xvals> etc.
 
-Unlike L<xvals|xvals> etc., if you supply a piddle input, you get 
+Unlike L</xvals> etc., if you supply a piddle input, you get 
 out a piddle of the default piddle type: double.   This causes less
 surprises than the previous default of keeping the data type of
 the input piddle since that rarely made sense in most usages.
@@ -355,10 +355,10 @@ $indices = ndcoords($type,@dimlist);
    ]
   ]
 
-  pdl> $a = zeroes(byte,2,3);        # $a is a 2x3 byte piddle
-  pdl> $b = ndcoords($a);            # $b inherits $a's type
-  pdl> $c = ndcoords(long,$a->dims); # $c is a long piddle, same dims as $b
-  pdl> help $b;
+  pdl> $w = zeroes(byte,2,3);        # $w is a 2x3 byte piddle
+  pdl> $y = ndcoords($w);            # $y inherits $w's type
+  pdl> $c = ndcoords(long,$w->dims); # $c is a long piddle, same dims as $y
+  pdl> help $y;
   This variable is   Byte D [2,2,3]              P            0.01Kb
   pdl> help $c;
   This variable is   Long D [2,2,3]              P            0.05Kb
@@ -380,8 +380,8 @@ sub PDL::ndcoords {
   $out = PDL->zeroes(@d);
   
   for my $d(0..$#dims) {
-    my $a = $out->index($d)->mv($d,0);
-    $a .= xvals($a);
+    my $w = $out->index($d)->mv($d,0);
+    $w .= xvals($w);
   }
 
   $out;
@@ -411,7 +411,7 @@ If C<hist> is run in list context, C<$xvals> gives the
 computed bin centres as double values.
 
 A nice idiom (with 
-L<PDL::Graphics::PGPLOT|PDL::Graphics::PGPLOT>) is
+L<PDL::Graphics::PGPLOT>) is
 
  bin hist $data;  # Plot histogram
 
@@ -461,7 +461,7 @@ as type double values.  C<$data> and C<$wt> should have
 the same dimensionality and extents.
 
 A nice idiom (with 
-L<PDL::Graphics::PGPLOT|PDL::Graphics::PGPLOT>) is
+L<PDL::Graphics::PGPLOT>) is
 
  bin whist $data, $wt;  # Plot histogram
 
@@ -519,7 +519,7 @@ Create array filled with a sequence of values
 
 =for usage
 
- $a = sequence($b); $a = sequence [OPTIONAL TYPE], @dims;
+ $w = sequence($y); $w = sequence [OPTIONAL TYPE], @dims;
 
 etc. see L<zeroes|PDL::Core/zeroes>.
 
@@ -594,8 +594,8 @@ or floating point datatypes.
 For a more general metric, one can define, e.g.,
 
  sub distance {
-   my ($a,$centre,$f) = @_;
-   my ($r) = $a->allaxisvals-$centre;
+   my ($w,$centre,$f) = @_;
+   my ($r) = $w->allaxisvals-$centre;
    $f->($r);
  }
  sub l1 { sumover(abs($_[0])); }
@@ -604,7 +604,7 @@ For a more general metric, one can define, e.g.,
 
 so now
 
- distance($a, $centre, \&euclid);
+ distance($w, $centre, \&euclid);
 
 will emulate rvals, while C<\&l1> and C<\&linfty> will generate other
 well-known norms. 
@@ -649,13 +649,13 @@ Fills a piddle with index values on Nth dimension
 
  $z = axisvals ($piddle, $nth);
 
-This is the routine, for which L<xvals|/xvals>, L<yvals|/yvals> etc
+This is the routine, for which L</xvals>, L</yvals> etc
 are mere shorthands. C<axisvals> can be used to fill along any dimension,
 using a parameter.
 
-See also L<allaxisvals|allaxisvals>, which generates all axis values 
-simultaneously in a form useful for L<range|range>, L<interpND|interpND>, 
-L<indexND|indexND>, etc.
+See also L</allaxisvals>, which generates all axis values 
+simultaneously in a form useful for L</range>, L</interpND>, 
+L</indexND>, etc.
 
 Note the 'from specification' style (see L<zeroes|PDL::Core/zeroes>) is
 not available here, for obvious reasons.
@@ -739,17 +739,17 @@ transpose rows and columns.
 
 =for usage
 
- $b = transpose($a); 
+ $y = transpose($w);
 
 =for example
 
- pdl> $a = sequence(3,2)
- pdl> p $a
+ pdl> $w = sequence(3,2)
+ pdl> p $w
  [
   [0 1 2]
   [3 4 5]
  ]                                                                               
- pdl> p transpose( $a )
+ pdl> p transpose( $w )
  [
   [0 3]
   [1 4]
